PostgrestClient class

The main client for interacting with the database.

Constructors

PostgrestClient(String url, {required Map<String, String> headers, FutureOr<Map<String, String>> headersProvider()?})

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
headersProvider FutureOr<Map<String, String>> Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

from(String table) PostgrestQueryBuilder
Starts a query builder for the given table.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited