vasabase_flutter library
Classes
- AuthClient
- The main client for interacting with the Authentication API.
- AuthStateChange
- FunctionsClient
- MFAChallengeResponse
- MFAEnrollResponse
- MFAFactor
- MFAVerifyResponse
- PostgresCDCConfig
- Configuration for Postgres CDC (Change Data Capture) subscription filters.
- PostgrestClient
- The main client for interacting with the database.
- PostgrestFilterBuilder
- A builder class for adding filters to a PostgREST query.
- PostgrestQueryBuilder
- A builder class for constructing PostgREST queries.
- PushClient
- RealtimeChannel
- A channel wrapping a WebSocket table subscription, providing filtered streams for presence, broadcast, and Postgres CDC events.
- RealtimeClient
- Session
- StorageClient
- StorageFileApi
- User
- Vasabase
- VasabaseClient
Extensions
Exceptions / Errors
- AuthException
- FunctionsException
- PostgrestException
- An exception thrown by the PostgREST client.
- PushException
- StorageException